==> zio-aws-waf_2.13-5.17.104.1-sources.jar: zio/aws/waf/model/ListTagsForResourceResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.waf.model.primitives.NextMarker
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceResponse(
    nextMarker: Option[NextMarker] = None,
    tagInfoForResource: Option[zio.aws.waf.model.TagInfoForResource] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse = {
    import ListTagsForResourceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(tagInfoForResource.map(value => value.buildAwsValue()))(
        _.tagInfoForResource
      )
      .build()
  }
  def asReadOnly: zio.aws.waf.model.ListTagsForResourceResponse.ReadOnly =
    zio.aws.waf.model.ListTagsForResourceResponse.wrap(buildAwsValue())
}
object ListTagsForResourceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.ListTagsForResourceResponse =
      zio.aws.waf.model.ListTagsForResourceResponse(
        nextMarker.map(value => value),
        tagInfoForResource.map(value => value.asEditable)
      )
    def nextMarker: Option[NextMarker]
    def tagInfoForResource
        : Option[zio.aws.waf.model.TagInfoForResource.ReadOnly]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getTagInfoForResource
        : ZIO[Any, AwsError, zio.aws.waf.model.TagInfoForResource.ReadOnly] =
      AwsError.unwrapOptionField("tagInfoForResource", tagInfoForResource)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ) extends zio.aws.waf.model.ListTagsForResourceResponse.ReadOnly {
    override val nextMarker: Option[NextMarker] = scala
      .Option(impl.nextMarker())
      .map(value => zio.aws.waf.model.primitives.NextMarker(value))
    override val tagInfoForResource
        : Option[zio.aws.waf.model.TagInfoForResource.ReadOnly] = scala
      .Option(impl.tagInfoForResource())
      .map(value => zio.aws.waf.model.TagInfoForResource.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ): zio.aws.waf.model.ListTagsForResourceResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-waf_2.13-5.19.8.4-sources.jar: zio/aws/waf/model/ListTagsForResourceResponse.scala <==
package zio.aws.waf.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import zio.aws.waf.model.primitives.NextMarker
import scala.jdk.CollectionConverters._
final case class ListTagsForResourceResponse(
    nextMarker: Optional[NextMarker] = Optional.Absent,
    tagInfoForResource: Optional[zio.aws.waf.model.TagInfoForResource] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse = {
    import ListTagsForResourceResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
      .builder()
      .optionallyWith(
        nextMarker.map(value => NextMarker.unwrap(value): java.lang.String)
      )(_.nextMarker)
      .optionallyWith(tagInfoForResource.map(value => value.buildAwsValue()))(
        _.tagInfoForResource
      )
      .build()
  }
  def asReadOnly: zio.aws.waf.model.ListTagsForResourceResponse.ReadOnly =
    zio.aws.waf.model.ListTagsForResourceResponse.wrap(buildAwsValue())
}
object ListTagsForResourceResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.waf.model.ListTagsForResourceResponse =
      zio.aws.waf.model.ListTagsForResourceResponse(
        nextMarker.map(value => value),
        tagInfoForResource.map(value => value.asEditable)
      )
    def nextMarker: Optional[NextMarker]
    def tagInfoForResource
        : Optional[zio.aws.waf.model.TagInfoForResource.ReadOnly]
    def getNextMarker: ZIO[Any, AwsError, NextMarker] =
      AwsError.unwrapOptionField("nextMarker", nextMarker)
    def getTagInfoForResource
        : ZIO[Any, AwsError, zio.aws.waf.model.TagInfoForResource.ReadOnly] =
      AwsError.unwrapOptionField("tagInfoForResource", tagInfoForResource)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ) extends zio.aws.waf.model.ListTagsForResourceResponse.ReadOnly {
    override val nextMarker: Optional[NextMarker] = zio.aws.core.internal
      .optionalFromNullable(impl.nextMarker())
      .map(value => zio.aws.waf.model.primitives.NextMarker(value))
    override val tagInfoForResource
        : Optional[zio.aws.waf.model.TagInfoForResource.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.tagInfoForResource())
        .map(value => zio.aws.waf.model.TagInfoForResource.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.waf.model.ListTagsForResourceResponse
  ): zio.aws.waf.model.ListTagsForResourceResponse.ReadOnly = new Wrapper(impl)
}
